pub struct HookState { /* private fields */ }Expand description
Stores keyed state across rebuilds
This enables component-level state management where each signal is identified by a unique string key rather than call order.
Implementations