StateMachine

Struct StateMachine 

pub struct StateMachine { /* private fields */ }
A state machine instance

Implementations

Source

impl StateMachine

pub fn new(initial_state: StateId, transitions: Vec<Transition>) -> Self

Create a new state machine with an initial state and transitions

pub fn builder(initial_state: StateId) -> StateMachineBuilder

Create a builder for a state machine

pub fn current_state(&self) -> StateId

Get the current state

pub fn is_in(&self, state: StateId) -> bool

Check if we’re in a specific state

pub fn history(&self) -> &[(StateId, EventId, StateId)]

Get transition history

pub fn clear_history(&mut self)

Clear transition history

pub fn can_send(&self, event: EventId) -> bool

Check if an event can trigger a transition from current state

pub fn send(&mut self, event: EventId) -> StateId

Send an event to the state machine, potentially triggering a transition

pub fn on_enter<F: FnMut() + Send + 'static>( &mut self, state: StateId, callback: F, )

Register an entry callback for a state

pub fn on_exit<F: FnMut() + Send + 'static>( &mut self, state: StateId, callback: F, )

Register an exit callback for a state